@@ -1,9 +1,8 @@
-# frozen_string_literal: true
-
 require "active_support/core_ext/array/conversions"
 require "active_support/core_ext/module/delegation"
 require "active_support/core_ext/object/acts_like"
 require "active_support/core_ext/string/filters"
+require "active_support/deprecation"
 
 module ActiveSupport
   # Provides accurate date and time measurements using Date#advance and
@@ -132,7 +131,7 @@ module ActiveSupport
     class << self
       # Creates a new Duration from string formatted according to ISO 8601 Duration.
       #
-      # See {ISO 8601}[https://en.wikipedia.org/wiki/ISO_8601#Durations] for more information.
+      # See {ISO 8601}[http://en.wikipedia.org/wiki/ISO_8601#Durations] for more information.
       # This method allows negative parts to be present in pattern.
       # If invalid string is provided, it will raise +ActiveSupport::Duration::ISO8601Parser::ParsingError+.
       def parse(iso8601duration)
@@ -193,6 +192,7 @@ module ActiveSupport
         end
 
         parts[:seconds] = remainder
+        parts.reject! { |k, v| v.zero? }
 
         new(value, parts)
       end
@@ -209,15 +209,11 @@ module ActiveSupport
     def initialize(value, parts) #:nodoc:
       @value, @parts = value, parts.to_h
       @parts.default = 0
-      @parts.reject! { |k, v| v.zero? }
     end
 
     def coerce(other) #:nodoc:
-      case other
-      when Scalar
+      if Scalar === other
         [other, self]
-      when Duration
-        [Scalar.new(other.value), self]
       else
         [Scalar.new(other), self]
       end
@@ -338,8 +334,8 @@ module ActiveSupport
     #   1.year.to_i     # => 31556952
     #
     # In such cases, Ruby's core
-    # Date[https://ruby-doc.org/stdlib/libdoc/date/rdoc/Date.html] and
-    # Time[https://ruby-doc.org/stdlib/libdoc/time/rdoc/Time.html] should be used for precision
+    # Date[http://ruby-doc.org/stdlib/libdoc/date/rdoc/Date.html] and
+    # Time[http://ruby-doc.org/stdlib/libdoc/time/rdoc/Time.html] should be used for precision
     # date and time arithmetic.
     def to_i
       @value.to_i
@@ -372,9 +368,8 @@ module ActiveSupport
     alias :before :ago
 
     def inspect #:nodoc:
-      return "0 seconds" if parts.empty?
-
       parts.
+        reduce(::Hash.new(0)) { |h, (l, r)| h[l] += r; h }.
         sort_by { |unit,  _ | PARTS.index(unit) }.
         map     { |unit, val| "#{val} #{val == 1 ? unit.to_s.chop : unit.to_s}" }.
         to_sentence(locale: ::I18n.default_locale)
@@ -384,6 +379,10 @@ module ActiveSupport
       to_i
     end
 
+    def respond_to_missing?(method, include_private = false) #:nodoc:
+      @value.respond_to?(method, include_private)
+    end
+
     def init_with(coder) #:nodoc:
       initialize(coder["value"], coder["parts"])
     end
@@ -418,12 +417,8 @@ module ActiveSupport
         end
       end
 
-      def respond_to_missing?(method, _)
-        value.respond_to?(method)
-      end
-
       def method_missing(method, *args, &block)
-        value.public_send(method, *args, &block)
+        value.send(method, *args, &block)
       end
 
       def raise_type_error(other)
